## Summary

<!-- What does this PR do? Keep it to 1-3 bullet points. -->

-

## Type of Change

- [ ] New detector rule
- [ ] Bug fix
- [ ] Feature enhancement
- [ ] Documentation
- [ ] Refactoring
- [ ] Test improvement

## Checklist

- [ ] I've added tests for my changes
- [ ] All existing tests pass (`pytest`)
- [ ] Linter passes (`ruff check src/ tests/`)
- [ ] I've updated documentation if needed
- [ ] I've updated CHANGELOG.md

## Related Issues

<!-- Link related issues: Fixes #123, Closes #456 -->

## Test Plan

<!-- How can reviewers verify this works? -->

-
